Apenas um projeto individual para uma Calculadora em lib em Python pra uma disciplina da universidade

Abstract:
Just an individual project for a Python lib Calculator for a university course

Matricula: 20201BSI0435
Disciplina: Projeto de Sistemas